==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/el.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "The mountpoint name contains invalid characters." : "Το όνομα σημείου προσάρτησης περιέχει μη έγκυρους χαρακτήρες.",
    "Not allowed to create a federated share with the same user server" : "Δεν είναι επιτρεπτή η δημιουργία ομόσπονδου διαμοιρασμού με τον ίδιο διακομιστή χρήστη",
    "Invalid or untrusted SSL certificate" : "Μη έγκυρο ή μη έμπιστο πιστοποιητικό SSL",
    "Could not authenticate to remote share, password might be wrong" : "Δεν ήταν δυνατή η πιστοποίηση στο απομακρυσμένο διαμοιρασμένο στοιχείο, μπορεί να είναι λάθος ο κωδικός πρόσβασης",
    "Storage not valid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Couldn't add remote share" : "Αδυναμία προσθήκης απομακρυσμένου κοινόχρηστου φακέλου",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Anonymous upload" : "Ανώνυμη μεταφόρτωση",
    "Click to select files or use drag & drop to upload" : "Κάντε κλικ για να επιλέξετε αρχεία ή χρησιμοποιήστε drag & drop για μεταφόρτωση",
    "Uploaded files" : "Μεταφόρτωση αρχείων",
    "Uploading..." : "Μεταφόρτωση...",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others share with you will show up here" : "Τα αρχεία και οι φάκελοι που άλλοι διαμοιράζονται με εσάς θα εμφανιστούν εδώ",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you share will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε θα εμφανιστούν εδώ",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you share by link will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε μέσω συνδέσμου θα εμφανιστούνε εδώ",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Remote share password" : "Κωδικός πρόσβασης απομακρυσμένου κοινόχρηστου φακέλου",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "You can upload into this folder" : "Μπορείτε να μεταφορτώσετε σε αυτόν τον φάκελο",
    "No ownCloud installation (7 or higher) found at {remote}" : "Δεν βρέθηκε εγκατάστση ownCloud (7 ή νεώτερη) στο {remote}",
    "Invalid ownCloud url" : "Άκυρη url ownCloud ",
    "Share" : "Διαμοιράστε",
    "No expiration date set" : "Δεν καθορίστηκε ημερομηνία λήξης",
    "Shared by" : "Διαμοιράστηκε από",
    "Sharing" : "Διαμοιρασμός",
    "Share API is disabled" : "Ο διαμοιρασμός ΑΡΙ είναι απενεργοποιημένος",
    "Wrong share ID, share doesn't exist" : "Εσφαλμένη διαδρομή, το αρχείο/ο φάκελος δεν υπάρχει",
    "Could not delete share" : "Αδυναμία διαγραφής διαμοιρασμένου",
    "Please specify a file or folder path" : "Παρακαλώ καθορίστε την διαδρομή του αρχείου ή του φακέλου",
    "Wrong path, file/folder doesn't exist" : "Εσφαλμένη διαδρομή, το αρχείο/ο φάκελος δεν υπάρχει",
    "Cannot remove all permissions" : "Δεν είναι δυνατή η κατάργηση όλων των δικαιωμάτων",
    "Please specify a valid user" : "Παρακαλώ καθορίστε έγκυρο χρήστη",
    "Group sharing is disabled by the administrator" : "O διαμοιρασμός μεταξύ της ιδίας ομάδας έχει απενεργοποιηθεί από το διαχειρηστή",
    "Please specify a valid group" : "Παρακαλώ καθορίστε μια έγκυρη ομάδα",
    "Public link sharing is disabled by the administrator" : "Ο δημόσιος διαμοιρασμός συνδέσμου έχει απενεργοποιηθεί από τον διαχειριστή",
    "Public upload disabled by the administrator" : "Η δημόσια μεταφόρτωση έχει απενεργοποιηθεί από τον διαχειριστή",
    "Public upload is only possible for publicly shared folders" : "Η δημόσια μεταφόρτωση είναι δυνατή μόνο για δημόσια διαμοιρασμένους φακέλους",
    "Invalid date, date format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία, η μορφή ημερομηνίας πρέπει να είναι YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Αποτυχία διαμοιρασμού %s γιατί το σύστημα δεν υποστηρίζει διαμοιρασμό τύπου %s",
    "Unknown share type" : "Άγνωστος τύπος διαμοιρασμού",
    "Not a directory" : "Δεν είναι κατάλογος",
    "Could not lock path" : "Αδυναμία κλειδώματος της διαδρομής",
    "Can't change permissions for public share links" : "Δεν μπορούν να γίνουν αλλαγές δικαιοδοσίας για δημόσιο διαμοιρασμό συνδέσμων",
    "Wrong or no update parameter given" : "Δόθηκε λανθασμένη ή χωρίς αναβάθμιση παράμετρος",
    "Cannot increase permissions" : "Τα δικαιώματα είναι περιορισμένα ",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ένα δημόσια διαμοιρασμένο αρχείο ή φάκελος <strong>ελήφθη</strong>",
    "You received a new remote share %2$s from %1$s" : "Λάβατε ένα νέο απομακρυσμένο κοινόχρηστο %2$s από %1$s",
    "You received a new remote share from %s" : "Λάβατε ένα νέο απομακρυσμένο κοινόχρηστο φάκελο από %s",
    "%1$s accepted remote share %2$s" : "Ο %1$s αποδέχθηκε τον απομακρυσμένο φάκελο %2$s",
    "%1$s declined remote share %2$s" : "Ο %1$s απέρριψε το απομακρυσμένο κοινόχρηστο %2$s",
    "%1$s unshared %2$s from you" : "Ο %1$s αναίρεσε το διαμοιρασμό του %2$s με εσάς",
    "Public shared folder %1$s was downloaded" : "Ο δημόσιος διαμοιρασμένος φάκελος %1$s ελήφθη",
    "Public shared file %1$s was downloaded" : "Το δημόσιο διαμοιρασμένο αρχείο %1$s ελήφθη",
    "You shared %1$s with %2$s" : "Διαμοιραστήκατε το %1$s με %2$s",
    "%2$s shared %1$s with %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με %3$s",
    "You removed the share of %2$s for %1$s" : "Έχετε αφαιρέσει το διαμοιρασμό του %2$s για  %1$s",
    "%2$s removed the share of %3$s for %1$s" : "Ο %2$s έχει αφαιρέσει τον διαμοιασμό του %3$s για %1$s",
    "You shared %1$s with group %2$s" : "Διαμοιραστήκατε %1$s με την ομάδα %2$s",
    "%2$s shared %1$s with group %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με την ομάδα %3$s",
    "You removed the share of group %2$s for %1$s" : "Έχετε αφαιρέσει το διαμοιρασμό της ομάδας %2$s για %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "Ο %2$s αφαίρεσε τον διαμοιρασμό της ομάδας %3$s για %1$s",
    "%2$s shared %1$s via link" : "Ο %2$s διαμοιράστηκε το %1$s μέσω συνδέσμου",
    "You shared %1$s via link" : "Μοιραστήκατε το %1$s μέσω συνδέσμου",
    "You removed the public link for %1$s" : "Αφαιρέσατε δημόσιο σύνδεσμο για %1$s",
    "%2$s removed the public link for %1$s" : "Ο %2$s αφαίρεση τον δημόσιο σύνδεσμο για %1$s",
    "Your public link for %1$s expired" : "Έληξε ο δημόσιος σύνδεσμος για %1$s",
    "The public link of %2$s for %1$s expired" : "Έληξε ο δημόσιος σύνδεσμος του %2$s για %1$s",
    "%2$s shared %1$s with you" : "Ο %2$s διαμοιράστηκε το %1$s με εσάς",
    "%2$s removed the share for %1$s" : "Ο %2$s αφαίρεση το κοινόχρηστο για %1$s",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Shared with %2$s" : "Διαμοιράστηκε με %2$s",
    "Shared with %3$s by %2$s" : "Διαμοιράστηκε με %3$s από %2$s",
    "Removed share for %2$s" : "Αφαίρεση διαμοιρασμού για %2$s",
    "%2$s removed share for %3$s" : "Ο %2$s αφαίρεσε τον διαμοιρασμό για %3$s",
    "Shared with group %2$s" : "Διαμοιράστηκε με την ομάδα %2$s",
    "Shared with group %3$s by %2$s" : "Διαμοιράστηκε με την ομάδα %3$s από %2$s",
    "Removed share of group %2$s" : "Αφαίρεση κοινόχρηστου από την ομάδα %2$s",
    "%2$s removed share of group %3$s" : "Ο/Η %2$s κατήργησε την κοινή χρήση της ομάδας %3$s",
    "Shared via link by %2$s" : "Διαμοιράστηκε μέσω συνδέσμου από %2$s",
    "Shared via public link" : "Διαμοιράστηκε μέσω δημόσιου συνδέσμου",
    "Removed public link" : "Αφαιρέθηκε ο δημόσιος σύνδεσμος",
    "%2$s removed public link" : "Ο/Η %2$s κατήργησε τον δημόσιο σύνδεσμο",
    "Public link expired" : "Έληξε ο δημόσιος σύνδεσμος",
    "Public link of %2$s expired" : "Έληξε ο δημόσιος σύνδεσμος του %2$s",
    "Shared by %2$s" : "Διαμοιράστηκε από %2$s",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Password" : "Κωδικός πρόσβασης",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Name" : "Όνομα",
    "Share time" : "Χρόνος διαμοιρασμού",
    "Expiration date" : "Ημερομηνία λήξης",
    "Sorry, this link doesn’t seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος μοιάζει να μην ισχύει πια.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more info, please ask the person who sent this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "%s is publicly shared" : "Το %s είναι κοινόχρηστο δημοσίως",
    "Add to your ownCloud" : "Προσθήκη στο ownCloud σου",
    "Download" : "Λήψη",
    "Download %s" : "Λήψη %s",
    "Direct link" : "Άμεσος σύνδεσμος"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/el.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "The mountpoint name contains invalid characters." : "Το όνομα σημείου προσάρτησης περιέχει μη έγκυρους χαρακτήρες.",
    "Not allowed to create a federated share with the same user server" : "Δεν είναι επιτρεπτή η δημιουργία ομόσπονδου διαμοιρασμού με τον ίδιο διακομιστή χρήστη",
    "Invalid or untrusted SSL certificate" : "Μη έγκυρο ή μη έμπιστο πιστοποιητικό SSL",
    "Could not authenticate to remote share, password might be wrong" : "Δεν ήταν δυνατή η πιστοποίηση στο απομακρυσμένο διαμοιρασμένο στοιχείο, μπορεί να είναι λάθος ο κωδικός πρόσβασης",
    "Storage not valid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Couldn't add remote share" : "Αδυναμία προσθήκης απομακρυσμένου κοινόχρηστου φακέλου",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Anonymous upload" : "Ανώνυμη μεταφόρτωση",
    "Click to select files or use drag & drop to upload" : "Κάντε κλικ για να επιλέξετε αρχεία ή χρησιμοποιήστε drag & drop για μεταφόρτωση",
    "Uploaded files" : "Μεταφόρτωση αρχείων",
    "Uploading..." : "Μεταφόρτωση...",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others share with you will show up here" : "Τα αρχεία και οι φάκελοι που άλλοι διαμοιράζονται με εσάς θα εμφανιστούν εδώ",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you share will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε θα εμφανιστούν εδώ",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you share by link will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε μέσω συνδέσμου θα εμφανιστούνε εδώ",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Remote share password" : "Κωδικός πρόσβασης απομακρυσμένου κοινόχρηστου φακέλου",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "You can upload into this folder" : "Μπορείτε να μεταφορτώσετε σε αυτόν τον φάκελο",
    "No ownCloud installation (7 or higher) found at {remote}" : "Δεν βρέθηκε εγκατάστση ownCloud (7 ή νεώτερη) στο {remote}",
    "Invalid ownCloud url" : "Άκυρη url ownCloud ",
    "Share" : "Διαμοιράστε",
    "No expiration date set" : "Δεν καθορίστηκε ημερομηνία λήξης",
    "Shared by" : "Διαμοιράστηκε από",
    "Sharing" : "Διαμοιρασμός",
    "Share API is disabled" : "Ο διαμοιρασμός ΑΡΙ είναι απενεργοποιημένος",
    "Wrong share ID, share doesn't exist" : "Εσφαλμένη διαδρομή, το αρχείο/ο φάκελος δεν υπάρχει",
    "Could not delete share" : "Αδυναμία διαγραφής διαμοιρασμένου",
    "Please specify a file or folder path" : "Παρακαλώ καθορίστε την διαδρομή του αρχείου ή του φακέλου",
    "Wrong path, file/folder doesn't exist" : "Εσφαλμένη διαδρομή, το αρχείο/ο φάκελος δεν υπάρχει",
    "Cannot remove all permissions" : "Δεν είναι δυνατή η κατάργηση όλων των δικαιωμάτων",
    "Please specify a valid user" : "Παρακαλώ καθορίστε έγκυρο χρήστη",
    "Group sharing is disabled by the administrator" : "O διαμοιρασμός μεταξύ της ιδίας ομάδας έχει απενεργοποιηθεί από το διαχειρηστή",
    "Please specify a valid group" : "Παρακαλώ καθορίστε μια έγκυρη ομάδα",
    "Public link sharing is disabled by the administrator" : "Ο δημόσιος διαμοιρασμός συνδέσμου έχει απενεργοποιηθεί από τον διαχειριστή",
    "Public upload disabled by the administrator" : "Η δημόσια μεταφόρτωση έχει απενεργοποιηθεί από τον διαχειριστή",
    "Public upload is only possible for publicly shared folders" : "Η δημόσια μεταφόρτωση είναι δυνατή μόνο για δημόσια διαμοιρασμένους φακέλους",
    "Invalid date, date format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία, η μορφή ημερομηνίας πρέπει να είναι YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Αποτυχία διαμοιρασμού %s γιατί το σύστημα δεν υποστηρίζει διαμοιρασμό τύπου %s",
    "Unknown share type" : "Άγνωστος τύπος διαμοιρασμού",
    "Not a directory" : "Δεν είναι κατάλογος",
    "Could not lock path" : "Αδυναμία κλειδώματος της διαδρομής",
    "Can't change permissions for public share links" : "Δεν μπορούν να γίνουν αλλαγές δικαιοδοσίας για δημόσιο διαμοιρασμό συνδέσμων",
    "Wrong or no update parameter given" : "Δόθηκε λανθασμένη ή χωρίς αναβάθμιση παράμετρος",
    "Cannot increase permissions" : "Τα δικαιώματα είναι περιορισμένα ",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ένα δημόσια διαμοιρασμένο αρχείο ή φάκελος <strong>ελήφθη</strong>",
    "You received a new remote share %2$s from %1$s" : "Λάβατε ένα νέο απομακρυσμένο κοινόχρηστο %2$s από %1$s",
    "You received a new remote share from %s" : "Λάβατε ένα νέο απομακρυσμένο κοινόχρηστο φάκελο από %s",
    "%1$s accepted remote share %2$s" : "Ο %1$s αποδέχθηκε τον απομακρυσμένο φάκελο %2$s",
    "%1$s declined remote share %2$s" : "Ο %1$s απέρριψε το απομακρυσμένο κοινόχρηστο %2$s",
    "%1$s unshared %2$s from you" : "Ο %1$s αναίρεσε το διαμοιρασμό του %2$s με εσάς",
    "Public shared folder %1$s was downloaded" : "Ο δημόσιος διαμοιρασμένος φάκελος %1$s ελήφθη",
    "Public shared file %1$s was downloaded" : "Το δημόσιο διαμοιρασμένο αρχείο %1$s ελήφθη",
    "You shared %1$s with %2$s" : "Διαμοιραστήκατε το %1$s με %2$s",
    "%2$s shared %1$s with %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με %3$s",
    "You removed the share of %2$s for %1$s" : "Έχετε αφαιρέσει το διαμοιρασμό του %2$s για  %1$s",
    "%2$s removed the share of %3$s for %1$s" : "Ο %2$s έχει αφαιρέσει τον διαμοιασμό του %3$s για %1$s",
    "You shared %1$s with group %2$s" : "Διαμοιραστήκατε %1$s με την ομάδα %2$s",
    "%2$s shared %1$s with group %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με την ομάδα %3$s",
    "You removed the share of group %2$s for %1$s" : "Έχετε αφαιρέσει το διαμοιρασμό της ομάδας %2$s για %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "Ο %2$s αφαίρεσε τον διαμοιρασμό της ομάδας %3$s για %1$s",
    "%2$s shared %1$s via link" : "Ο %2$s διαμοιράστηκε το %1$s μέσω συνδέσμου",
    "You shared %1$s via link" : "Μοιραστήκατε το %1$s μέσω συνδέσμου",
    "You removed the public link for %1$s" : "Αφαιρέσατε δημόσιο σύνδεσμο για %1$s",
    "%2$s removed the public link for %1$s" : "Ο %2$s αφαίρεση τον δημόσιο σύνδεσμο για %1$s",
    "Your public link for %1$s expired" : "Έληξε ο δημόσιος σύνδεσμος για %1$s",
    "The public link of %2$s for %1$s expired" : "Έληξε ο δημόσιος σύνδεσμος του %2$s για %1$s",
    "%2$s shared %1$s with you" : "Ο %2$s διαμοιράστηκε το %1$s με εσάς",
    "%2$s removed the share for %1$s" : "Ο %2$s αφαίρεση το κοινόχρηστο για %1$s",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Shared with %2$s" : "Διαμοιράστηκε με %2$s",
    "Shared with %3$s by %2$s" : "Διαμοιράστηκε με %3$s από %2$s",
    "Removed share for %2$s" : "Αφαίρεση διαμοιρασμού για %2$s",
    "%2$s removed share for %3$s" : "Ο %2$s αφαίρεσε τον διαμοιρασμό για %3$s",
    "Shared with group %2$s" : "Διαμοιράστηκε με την ομάδα %2$s",
    "Shared with group %3$s by %2$s" : "Διαμοιράστηκε με την ομάδα %3$s από %2$s",
    "Removed share of group %2$s" : "Αφαίρεση κοινόχρηστου από την ομάδα %2$s",
    "%2$s removed share of group %3$s" : "Ο/Η %2$s κατήργησε την κοινή χρήση της ομάδας %3$s",
    "Shared via link by %2$s" : "Διαμοιράστηκε μέσω συνδέσμου από %2$s",
    "Shared via public link" : "Διαμοιράστηκε μέσω δημόσιου συνδέσμου",
    "Removed public link" : "Αφαιρέθηκε ο δημόσιος σύνδεσμος",
    "%2$s removed public link" : "Ο/Η %2$s κατήργησε τον δημόσιο σύνδεσμο",
    "Public link expired" : "Έληξε ο δημόσιος σύνδεσμος",
    "Public link of %2$s expired" : "Έληξε ο δημόσιος σύνδεσμος του %2$s",
    "Shared by %2$s" : "Διαμοιράστηκε από %2$s",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Password" : "Κωδικός πρόσβασης",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Name" : "Όνομα",
    "Share time" : "Χρόνος διαμοιρασμού",
    "Expiration date" : "Ημερομηνία λήξης",
    "Sorry, this link doesn’t seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος μοιάζει να μην ισχύει πια.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more info, please ask the person who sent this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "%s is publicly shared" : "Το %s είναι κοινόχρηστο δημοσίως",
    "Add to your ownCloud" : "Προσθήκη στο ownCloud σου",
    "Download" : "Λήψη",
    "Download %s" : "Λήψη %s",
    "Direct link" : "Άμεσος σύνδεσμος",
    "Pending" : "Εκκρεμεί",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Declined" : "Απορρίφθηκε"
},
"nplurals=2; plural=(n != 1);");
